==> collective.zipfiletransport-2.1.2.tar.gz: collective.zipfiletransport-2.1.2/collective/zipfiletransport/browser/widgets.py <==
##################################################################################
#    Copyright (C) 2004-2007 Utah State University, All rights reserved.          
#                                                                                 
#    This program is free software; you can redistribute it and/or modify         
#    it under the terms of the GNU General Public License as published by         
#    the Free Software Foundation; either version 2 of the License, or            
#    (at your option) any later version.                                          
#                                                                                 
#    This program is distributed in the hope that it will be useful,              
#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
#    GNU General Public License for more details.                                 
#                                                                                 
#    You should have received a copy of the GNU General Public License            
#    along with this program; if not, write to the Free Software                  
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
#                                                                                 
##################################################################################

__author__ = 'Brent Lambert, David Ray, Jon Thomas'
__docformat__ = 'restructuredtext'
__version__ = "$Revision: 1 $"[11:-2]

from zope.app.form.browser.textwidgets import TextWidget

class ExportWidget(TextWidget):
    """ Widget for Export Form. """

    def __init__(self, field, request):
        """ Initialize the widget.  """
        super(ExportWidget, self).__init__(field, request)


    def __call__(self):
        widgettext = TextWidget.__call__(self)
        widgettext += self.context.context.context.restrictedTraverse('@@export_widget')()        
        return widgettext

==> collective.zipfiletransport-2.1.3-rc1.tar.gz: collective.zipfiletransport-2.1.3-rc1/collective/zipfiletransport/browser/widgets.py <==
##################################################################################
#    Copyright (c) 2004-2009 Utah State University, All rights reserved. 
#    Portions copyright 2009 Massachusetts Institute of Technology, All rights reserved.
#                                                                                 
#    This program is free software; you can redistribute it and/or modify         
#    it under the terms of the GNU General Public License as published by         
#    the Free Software Foundation; either version 2 of the License, or            
#    (at your option) any later version.                                          
#                                                                                 
#    This program is distributed in the hope that it will be useful,              
#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
#    GNU General Public License for more details.                                 
#                                                                                 
#    You should have received a copy of the GNU General Public License            
#    along with this program; if not, write to the Free Software                  
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
#                                                                                 
##################################################################################

__author__  = '''Brent Lambert, David Ray, Jon Thomas'''
__version__   = '$ Revision 0.0 $'[11:-2]

from zope.app.form.browser.textwidgets import TextWidget

class ExportWidget(TextWidget):
    """ Widget for Export Form. """

    def __init__(self, field, request):
        """ Initialize the widget.  """
        super(ExportWidget, self).__init__(field, request)


    def __call__(self):
        widgettext = TextWidget.__call__(self)
        widgettext += self.context.context.context.restrictedTraverse('@@export_widget')()        
        return widgettext
